@@ -126,8 +126,7 @@ bool MimeTypeWriter::write()
 
 void MimeTypeWriter::runUpdateMimeDatabase()
 {
-    const QString localPackageDir = QStandardPaths::writableLocation(
-        QStandardPaths::GenericDataLocation) + QLatin1String("/mime/");
+    const QString localPackageDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/mime/");
     Q_ASSERT(!localPackageDir.isEmpty());
     KProcess proc;
     proc << QStringLiteral("update-mime-database");
@@ -148,9 +147,7 @@ QString MimeTypeWriterPrivate::localFilePath() const
     // and in ~/.local we don't really expect other packages to be installed anyway...
     QString baseName = m_mimeType;
     baseName.replace(QLatin1Char('/'), QLatin1Char('-'));
-    QString packagesDirName
-        = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)
-          + QLatin1String("/mime/") + QStringLiteral("packages/");
+    QString packagesDirName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/mime/") + QStringLiteral("packages/");
     // create the directory, the saving will fail if it doesn't exist (bug#356237)
     QDir(packagesDirName).mkpath(QStringLiteral("."));
     return packagesDirName + baseName + QStringLiteral(".xml");
@@ -160,9 +157,8 @@ static QString existingDefinitionFile(const QString &mimeType)
 {
     QString baseName = mimeType;
     baseName.replace(QLatin1Char('/'), QLatin1Char('-'));
-    return QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String(
-                                      "mime/") + QStringLiteral(
-                                      "packages/") + baseName + QStringLiteral(".xml"));
+    return QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                  QLatin1String("mime/") + QStringLiteral("packages/") + baseName + QStringLiteral(".xml"));
 }
 
 bool MimeTypeWriter::hasDefinitionFile(const QString &mimeType)
@@ -176,9 +172,7 @@ void MimeTypeWriter::removeOwnMimeType(const QString &mimeType)
     Q_ASSERT(!file.isEmpty());
     QFile::remove(file);
     // We must also remove the generated XML file, update-mime-database doesn't do that, for unknown media types
-    QString xmlFile
-        = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String(
-                                     "mime/") + mimeType + QStringLiteral(".xml"));
+    QString xmlFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("mime/") + mimeType + QStringLiteral(".xml"));
     QFile::remove(xmlFile);
 }
 
